from setuptools import find_packages, setup

setup(
    name='openirt',
    packages = find_packages(include=['openirt']),
    url='https://gitlab.com/pleased/...',
    version='0.1',
    description='Item response theory toolkit',
    author='Johan Hay',
    license='MIT',
)